#eSeq: process sequence

## introduction
The tool known as eSeq can offer methods for process various sequences. Those sequence could be DNA, RNA, amino acid sequence, etc.
- Detect specific sequence, namely palindromic, similarity etc.
- Iterator of sequence
- Trim adapter from sequence.
- Detect motif

quick installation
```
pip install eseq
```

## devlopment

Launch virtual environment.
```
git clone git@github.com:Tiezhengyuan/bio_sequence.git
cd bio_sequence
source venv/bin/activate
```

Run unit tests
```
pytest tests/unittests
```


## Quick tour

```
import eseq
```

